==> StanHeaders_2.14.0-1.tar.gz: StanHeaders/inst/include/src/stan/mcmc/hmc/static/adapt_unit_e_static_hmc.hpp <==
#ifndef STAN_MCMC_HMC_STATIC_ADAPT_UNIT_E_STATIC_HMC_HPP
#define STAN_MCMC_HMC_STATIC_ADAPT_UNIT_E_STATIC_HMC_HPP

#include <stan/interface_callbacks/writer/base_writer.hpp>
#include <stan/mcmc/hmc/static/unit_e_static_hmc.hpp>
#include <stan/mcmc/stepsize_adapter.hpp>

namespace stan {
  namespace mcmc {
    /**
     * Hamiltonian Monte Carlo implementation using the endpoint
     * of trajectories with a static integration time with a
     * Gaussian-Euclidean disintegration and unit metric and
     * adaptive step size
     */
    template <class Model, class BaseRNG>
    class adapt_unit_e_static_hmc : public unit_e_static_hmc<Model, BaseRNG>,
                                    public stepsize_adapter {
    public:
      adapt_unit_e_static_hmc(const Model& model, BaseRNG& rng)
        : unit_e_static_hmc<Model, BaseRNG>(model, rng) { }

      ~adapt_unit_e_static_hmc() { }

      sample
      transition(sample& init_sample,
                 interface_callbacks::writer::base_writer& info_writer,
                 interface_callbacks::writer::base_writer& error_writer) {
        sample s
          = unit_e_static_hmc<Model, BaseRNG>::transition(init_sample,
                                                          info_writer,
                                                          error_writer);

        if (this->adapt_flag_) {
          this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
                                                    s.accept_stat());
          this->update_L_();
        }

        return s;
      }

      void disengage_adaptation() {
        base_adapter::disengage_adaptation();
        this->stepsize_adaptation_.complete_adaptation(this->nom_epsilon_);
      }
    };

  }  // mcmc
}  // stan
#endif

==> StanHeaders_2.15.0-1.tar.gz: StanHeaders/inst/include/src/stan/mcmc/hmc/static/adapt_unit_e_static_hmc.hpp <==
#ifndef STAN_MCMC_HMC_STATIC_ADAPT_UNIT_E_STATIC_HMC_HPP
#define STAN_MCMC_HMC_STATIC_ADAPT_UNIT_E_STATIC_HMC_HPP

#include <stan/callbacks/writer.hpp>
#include <stan/mcmc/hmc/static/unit_e_static_hmc.hpp>
#include <stan/mcmc/stepsize_adapter.hpp>

namespace stan {
  namespace mcmc {
    /**
     * Hamiltonian Monte Carlo implementation using the endpoint
     * of trajectories with a static integration time with a
     * Gaussian-Euclidean disintegration and unit metric and
     * adaptive step size
     */
    template <class Model, class BaseRNG>
    class adapt_unit_e_static_hmc : public unit_e_static_hmc<Model, BaseRNG>,
                                    public stepsize_adapter {
    public:
      adapt_unit_e_static_hmc(const Model& model, BaseRNG& rng)
        : unit_e_static_hmc<Model, BaseRNG>(model, rng) { }

      ~adapt_unit_e_static_hmc() { }

      sample
      transition(sample& init_sample,
                 callbacks::writer& info_writer,
                 callbacks::writer& error_writer) {
        sample s
          = unit_e_static_hmc<Model, BaseRNG>::transition(init_sample,
                                                          info_writer,
                                                          error_writer);

        if (this->adapt_flag_) {
          this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
                                                    s.accept_stat());
          this->update_L_();
        }

        return s;
      }

      void disengage_adaptation() {
        base_adapter::disengage_adaptation();
        this->stepsize_adaptation_.complete_adaptation(this->nom_epsilon_);
      }
    };

  }  // mcmc
}  // stan
#endif
